@@ -106,7 +106,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 110 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 110 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -114,7 +114,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 121 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 121 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -325,6 +325,7 @@ pref("capability.policy.mailnews.Window.screenY.set", "noAccess");
 pref("capability.policy.mailnews.Window.sizeToContent", "noAccess");
 pref("capability.policy.mailnews.document.load", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.getInterface", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.responseXML", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.responseText", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.status", "noAccess");
@@ -392,6 +393,7 @@ pref("capability.policy.mailnews.WebServiceProxyFactory.onError", "noAccess");
 
 // XMLExtras
 pref("capability.policy.default.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.default.XMLHttpRequest.getInterface", "noAccess");
 pref("capability.policy.default.DOMParser.parseFromStream", "noAccess");
 
 // Clipboard
@@ -460,7 +462,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 469 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 471 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -580,6 +582,7 @@ pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
 pref("network.IDN.whitelist.io", true);
+pref("network.IDN.whitelist.is", true);
 pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
@@ -654,7 +657,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 668 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 671 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -789,7 +792,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 837 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 840 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -806,7 +809,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 854 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 857 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -939,15 +942,15 @@ pref("dom.max_script_run_time", 5);
 
 pref("svg.enabled", true);
 
-//@line 1317 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1320 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1504 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1507 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1693 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1696 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1774 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1777 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1777 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1780 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1023,7 +1026,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1853 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1856 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1082,7 +1085,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 1972 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1975 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1304,11 +1307,11 @@ pref("print.postscript.nativecode.zh-TW", "big5");
 pref("print.postscript.nativefont.zh-TW", "ShanHeiSun-Light-B5-H");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2196 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2199 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2264 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2267 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2290 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2293 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2310 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2313 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
